==> jc-1.4.0.tar.gz: javax/security/auth/callback/LanguageCallback.h <==
// public class javax.security.auth.callback.LanguageCallback

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5d2a354b77c5048e javax_security_auth_callback_LanguageCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_LanguageCallback_H_
#define _JC_javax_security_auth_callback_LanguageCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_LanguageCallback$sub_refs	_jc_javax_security_auth_callback_LanguageCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_LanguageCallback$sub_nonrefs	_jc_javax_security_auth_callback_LanguageCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_LanguageCallback$refs	_jc_javax_security_auth_callback_LanguageCallback$refs;
typedef struct _jc_javax_security_auth_callback_LanguageCallback$nonrefs	_jc_javax_security_auth_callback_LanguageCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_LanguageCallback$object	_jc_javax_security_auth_callback_LanguageCallback$object;

typedef const struct _jc_javax_security_auth_callback_LanguageCallback$vmethods	_jc_javax_security_auth_callback_LanguageCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_LanguageCallback$vtable	_jc_javax_security_auth_callback_LanguageCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_LanguageCallback$vtype	_jc_javax_security_auth_callback_LanguageCallback$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_LanguageCallback$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *);

// Virtual methods
extern struct _jc_java_util_Locale$object *_jc_javax_security_auth_callback_LanguageCallback$method$getLocale$0f16f3de840c0c1e(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *);
extern void _jc_javax_security_auth_callback_LanguageCallback$method$setLocale$6eaa1a56408d8bc9(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *, struct _jc_java_util_Locale$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$getLocale$0f16f3de840c0c1e;
extern _jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$setLocale$6eaa1a56408d8bc9;

// Virtual methods structure
struct _jc_javax_security_auth_callback_LanguageCallback$vmethods {
	struct _jc_java_util_Locale$object	*(*getLocale$0f16f3de840c0c1e)(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *);
	void	(*setLocale$6eaa1a56408d8bc9)(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *, struct _jc_java_util_Locale$object *);
};

// Vtable
struct _jc_javax_security_auth_callback_LanguageCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_LanguageCallback$vmethods	javax_security_auth_callback_LanguageCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_LanguageCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_LanguageCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_LanguageCallback$sub_refs {
	struct _jc_java_util_Locale$object	*locale;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_LanguageCallback$refs {
    _jc_javax_security_auth_callback_LanguageCallback$sub_refs	javax_security_auth_callback_LanguageCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_LanguageCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_LanguageCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_LanguageCallback$sub_nonrefs	javax_security_auth_callback_LanguageCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_LanguageCallback$object {
	_jc_javax_security_auth_callback_LanguageCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_LanguageCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_LanguageCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_LanguageCallback$vtype _jc_javax_security_auth_callback_LanguageCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_LanguageCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_LanguageCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_LanguageCallback_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/callback/LanguageCallback.h <==
// public class javax.security.auth.callback.LanguageCallback

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5d2a354b77c5048e javax_security_auth_callback_LanguageCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_LanguageCallback_H_
#define _JC_javax_security_auth_callback_LanguageCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_LanguageCallback$sub_refs	_jc_javax_security_auth_callback_LanguageCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_LanguageCallback$sub_nonrefs	_jc_javax_security_auth_callback_LanguageCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_LanguageCallback$refs	_jc_javax_security_auth_callback_LanguageCallback$refs;
typedef struct _jc_javax_security_auth_callback_LanguageCallback$nonrefs	_jc_javax_security_auth_callback_LanguageCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_LanguageCallback$object	_jc_javax_security_auth_callback_LanguageCallback$object;

typedef const struct _jc_javax_security_auth_callback_LanguageCallback$vmethods	_jc_javax_security_auth_callback_LanguageCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_LanguageCallback$vtable	_jc_javax_security_auth_callback_LanguageCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_LanguageCallback$vtype	_jc_javax_security_auth_callback_LanguageCallback$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_LanguageCallback$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_Locale$object *_jc_javax_security_auth_callback_LanguageCallback$method$getLocale$0f16f3de840c0c1e(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_LanguageCallback$method$setLocale$6eaa1a56408d8bc9(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$getLocale$0f16f3de840c0c1e;
extern _jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$setLocale$6eaa1a56408d8bc9;

// Virtual methods structure
struct _jc_javax_security_auth_callback_LanguageCallback$vmethods {
	struct _jc_java_util_Locale$object	*(*getLocale$0f16f3de840c0c1e)(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *) _JC_JCNI_ATTR;
	void	(*setLocale$6eaa1a56408d8bc9)(_jc_env *, struct _jc_javax_security_auth_callback_LanguageCallback$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_callback_LanguageCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_LanguageCallback$vmethods	javax_security_auth_callback_LanguageCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_LanguageCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_LanguageCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_LanguageCallback$sub_refs {
	struct _jc_java_util_Locale$object	*locale;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_LanguageCallback$refs {
    _jc_javax_security_auth_callback_LanguageCallback$sub_refs	javax_security_auth_callback_LanguageCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_LanguageCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_LanguageCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_LanguageCallback$sub_nonrefs	javax_security_auth_callback_LanguageCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_LanguageCallback$object {
	_jc_javax_security_auth_callback_LanguageCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_LanguageCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_LanguageCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_LanguageCallback$vtype _jc_javax_security_auth_callback_LanguageCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_LanguageCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_LanguageCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_LanguageCallback_H_ */
